@@ -31,12 +31,13 @@ typedef struct {
 	char       *original_path;    /* path read from command line. */
 	char       *full_path;        /* "/" + original_path. */
 	char       *link;
-	long long   size;
+	guint64     size;
 	time_t      modified;
 
 	char       *name;             /* The file name. */
 	char       *path;             /* The directory. */
 	const char *type;             /* The mime type. */
+	gboolean    encrypted;        /* Wether this file is password. */ 
 
 	/* Additional data. */
 
